import { consolidate } from '../consolidate.js';
import { mergeOptionalWithDefaults } from '../utils/mergeOptionalWithDefaults.js';
import { findWordExact } from './find.js';
import { trieRootToITrieRoot } from './trie.js';
import { createTrieRootFromList, iteratorTrieWords } from './trie-util.js';
export class TrieNodeTrie {
    constructor(root) {
        this.root = root;
        this.info = mergeOptionalWithDefaults(root);
    }
    get iTrieRoot() {
        return this._iTrieRoot || (this._iTrieRoot = trieRootToITrieRoot(this.root));
    }
    getRoot() {
        return this.iTrieRoot;
    }
    words() {
        return iteratorTrieWords(this.root);
    }
    has(word) {
        return findWordExact(this.root, word);
    }
    isForbiddenWord(word) {
        return findWordExact(this.root.c[this.root.forbiddenWordPrefix], word);
    }
    hasForbiddenWords() {
        const root = this.root;
        return !!root.c[root.forbiddenWordPrefix];
    }
    static createFromWords(words, options) {
        const root = createTrieRootFromList(words, options);
        return new TrieNodeTrie(root);
    }
    static createFromWordsAndConsolidate(words, options) {
        const root = createTrieRootFromList(words, options);
        return new TrieNodeTrie(consolidate(root));
    }
}
